#!/usr/bin/env python

# Copyright and license: Please refer to LICENSE.TXT

import sys
import os
import os.path
import string
import re
import time
import base64

_selfpath=(os.path.dirname(os.path.realpath(__file__)).split('/'))[:-2]
_selfpath.append('pylibs')
_libspath='/'.join(_selfpath)
sys.path.append(_libspath)

from s2p import *
from s2p_logger import *

S2P_CONF_SYSTEM	= xml_to_array(CORE_PATH_CONFIG+'/system.xml')
S2P_CONF_PROXY	= xml_to_array(CORE_PATH_CONFIG+'/proxy.xml')

##########################################################################################
# Verifica dati in ingresso
if len(sys.argv) < 2:
	print "Usage: "+sys.argv[0]+" username"
	sys.exit(-1)

S2P_CONF_SKYPE	= xml_to_array(CORE_PATH_CONFIG+'/skype.xml', 0)

# Lettura dati
user_name=sys.argv[1]

# Validazione dati
if not re.match(r'^[\w\-_\.]+$', user_name) or re.match(r'^\.', user_name):
	print "Dangerous username"
	sys.exit(-1)

# Ricerca info utente
S2P_USER_INFO=0

for item in S2P_CONF_SKYPE['item'].values():
	if item['+']['skype'][0]['+']['username'][0]['#'] == user_name:
		S2P_USER_INFO=xml_simplify_array(item)
		break

if not S2P_USER_INFO:
	print "Unknown user"
	sys.exit(-1)

if S2P_USER_INFO['enabled'] != "true":
	print "User is disabled"
	sys.exit(-1)

##########################################################################################
# Costruzione home directory

home=CORE_PATH_VH+'/'+user_name

S2P_REBUILD_HOME=0
if not os.path.isfile(home+'/.Skype/'+user_name+'/config.xml'): S2P_REBUILD_HOME=1

# Creazione della virtual home e delle cartelle
if not os.path.isdir(home): os.mkdir(home)
if not os.path.isdir(home+'/.vnc'): os.mkdir(home+'/.vnc')
if not os.path.isdir(home+'/.Skype'): os.mkdir(home+'/.Skype')
if not os.path.isdir(home+'/.Skype/'+user_name): os.mkdir(home+'/.Skype/'+user_name)

# Copia dei files di configurazione base di Skype
config_xml=home+'/.Skype/'+user_name+'/config.xml'
if S2P_REBUILD_HOME:
	config_xml_skel=CORE_PATH_MISC+'/skypeconf/config.xml'

	txt=""
	fp=open(config_xml_skel, "r")
	for line in fp: txt=txt+line
	fp.close()

	txt=set_vars(txt,
		{
			'sysname': re.sub(r'\W', '', S2P_CONF_SYSTEM['hq']['sysname'].lower()),
			'lastpath': home
		}
	)

	fp=open(config_xml, "w")
	fp.write(txt)
	fp.close()
	os.chmod(config_xml, 0600)

# Configurazione XML condivisa
shared_xml=home+'/.Skype/shared.xml'
if S2P_REBUILD_HOME:
	shared_xml_skel=CORE_PATH_MISC+'/skypeconf/shared.xml'

	txt=""
	fp=open(shared_xml_skel, "r")
	for line in fp: txt=txt+line
	fp.close()

	txt=set_vars(txt,
		{
			'accountname': user_name
		}
	)

	fp=open(shared_xml, "w")
	fp.write(txt)
	fp.close()
	os.chmod(shared_xml, 0600)

# Reset proxy
txt=""
fp=open(shared_xml, "r")
for line in fp: txt=txt+line
fp.close()

txt=re.sub(r'(?i)\s*<httpsproxy>([.\s\S]+)</httpsproxy>', "", txt)

# Configurazione Proxy
if S2P_CONF_PROXY['enabled'] == "true":
	piece = "\n    <Connection>\n";
	piece = piece+"      <HttpsProxy>\n";
	piece = piece+"        <Addr>"+S2P_CONF_PROXY['host']+":"+S2P_CONF_PROXY['port']+"</Addr>\n";
	piece = piece+"        <Enable>1</Enable>\n";

	if S2P_CONF_PROXY['user']:
		piece = piece+"        <User>"+S2P_CONF_PROXY['user']+"</User>\n";

	if S2P_CONF_PROXY['pass']:
		piece = piece+"        <Pwd>"+base64.b64encode(S2P_CONF_PROXY['pass'])+"</Pwd>\n";
	
	piece = piece+"      </HttpsProxy>";
	
	txt=re.sub(r'(?i)\s*<connection>', piece, txt)
	
elif S2P_CONF_PROXY.has_key('peruser') and S2P_CONF_PROXY['peruser'].has_key(user_name):
	piece = "\n    <Connection>\n";
	piece = piece+"      <HttpsProxy>\n";
	piece = piece+"        <Addr>"+S2P_CONF_PROXY['peruser'][user_name]['host']+":"+S2P_CONF_PROXY['peruser'][user_name]['port']+"</Addr>\n";
	piece = piece+"        <Enable>1</Enable>\n";

	if S2P_CONF_PROXY['peruser'][user_name]['user']:
		piece = piece+"        <User>"+S2P_CONF_PROXY['peruser'][user_name]['user']+"</User>\n";

	if S2P_CONF_PROXY['peruser'][user_name]['pass']:
		piece = piece+"        <Pwd>"+base64.b64encode(S2P_CONF_PROXY['peruser'][user_name]['pass'])+"</Pwd>\n";
	
	piece = piece+"      </HttpsProxy>";
	
	txt=re.sub(r'(?i)\s*<connection>', piece, txt)

# Riscrittura Shared XML con o senza proxy
fp=open(shared_xml, "w")
fp.write(txt)
fp.close()
os.chmod(shared_xml, 0600)

# Filetransfer
txt=""
fp=open(config_xml, "r")
for line in fp: txt=txt+line
fp.close()

if S2P_USER_INFO['filetransfer']['enabled'] == "true":
	txt=re.sub(r'(?i)<AutoAcceptTransfers>(\d+)</AutoAcceptTransfers>', "<AutoAcceptTransfers>1</AutoAcceptTransfers>", txt)
else:
	txt=re.sub(r'(?i)<AutoAcceptTransfers>(\d+)</AutoAcceptTransfers>', "<AutoAcceptTransfers>0</AutoAcceptTransfers>", txt)

#txt=re.sub(r'<SoundDevice>\d+</SoundDevice>', '<SoundDevice>'+str(1+(int(S2P_USER_INFO['vnc']['screen']) % 4))+'</SoundDevice>', txt)

# Riscrittura config XML con o senza Filetransfer
fp=open(config_xml, "w")
fp.write(txt)
fp.close()
os.chmod(config_xml, 0600)
sys.exit(0)
